# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..resampling import ApplyTransformsToPoints


def test_ApplyTransformsToPoints_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        dimension=dict(argstr="--dimensionality %d",),
        environ=dict(nohash=True, usedefault=True,),
        input_file=dict(argstr="--input %s", extensions=None, mandatory=True,),
        invert_transform_flags=dict(),
        num_threads=dict(nohash=True, usedefault=True,),
        output_file=dict(
            argstr="--output %s",
            hash_files=False,
            name_source=["input_file"],
            name_template="%s_transformed.csv",
        ),
        transforms=dict(argstr="%s", mandatory=True,),
    )
    inputs = ApplyTransformsToPoints.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ApplyTransformsToPoints_outputs():
    output_map = dict(output_file=dict(extensions=None,),)
    outputs = ApplyTransformsToPoints.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brainsuite import SVReg


def test_SVReg_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        atlasFilePrefix=dict(argstr="'%s'", position=1,),
        curveMatchingInstructions=dict(argstr="'-cur %s'",),
        dataSinkDelay=dict(argstr="%s",),
        displayModuleName=dict(argstr="'-m'",),
        displayTimestamps=dict(argstr="'-t'",),
        environ=dict(nohash=True, usedefault=True,),
        iterations=dict(argstr="'-H %d'",),
        keepIntermediates=dict(argstr="'-k'",),
        pialSurfaceMaskDilation=dict(argstr="'-D %d'",),
        refineOutputs=dict(argstr="'-r'",),
        shortMessages=dict(argstr="'-gui'",),
        skipToIntensityReg=dict(argstr="'-p'",),
        skipToVolumeReg=dict(argstr="'-s'",),
        skipVolumetricProcessing=dict(argstr="'-S'",),
        subjectFilePrefix=dict(argstr="'%s'", mandatory=True, position=0,),
        useCerebrumMask=dict(argstr="'-C'",),
        useManualMaskFile=dict(argstr="'-cbm'",),
        useMultiThreading=dict(argstr="'-P'",),
        useSingleThreading=dict(argstr="'-U'",),
        verbosity0=dict(
            argstr="'-v0'", xor=("verbosity0", "verbosity1", "verbosity2"),
        ),
        verbosity1=dict(
            argstr="'-v1'", xor=("verbosity0", "verbosity1", "verbosity2"),
        ),
        verbosity2=dict(argstr="'v2'", xor=("verbosity0", "verbosity1", "verbosity2"),),
    )
    inputs = SVReg.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..gtract import compareTractInclusion


def test_compareTractInclusion_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        closeness=dict(argstr="--closeness %f",),
        environ=dict(nohash=True, usedefault=True,),
        numberOfPoints=dict(argstr="--numberOfPoints %d",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        standardFiber=dict(argstr="--standardFiber %s", extensions=None,),
        testFiber=dict(argstr="--testFiber %s", extensions=None,),
        testForBijection=dict(argstr="--testForBijection ",),
        testForFiberCardinality=dict(argstr="--testForFiberCardinality ",),
        writeXMLPolyDataFile=dict(argstr="--writeXMLPolyDataFile ",),
    )
    inputs = compareTractInclusion.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_compareTractInclusion_outputs():
    output_map = dict()
    outputs = compareTractInclusion.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..surface import GrayscaleModelMaker


def test_GrayscaleModelMaker_inputs():
    input_map = dict(
        InputVolume=dict(argstr="%s", extensions=None, position=-2,),
        OutputGeometry=dict(argstr="%s", hash_files=False, position=-1,),
        args=dict(argstr="%s",),
        decimate=dict(argstr="--decimate %f",),
        environ=dict(nohash=True, usedefault=True,),
        name=dict(argstr="--name %s",),
        pointnormals=dict(argstr="--pointnormals ",),
        smooth=dict(argstr="--smooth %d",),
        splitnormals=dict(argstr="--splitnormals ",),
        threshold=dict(argstr="--threshold %f",),
    )
    inputs = GrayscaleModelMaker.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_GrayscaleModelMaker_outputs():
    output_map = dict(OutputGeometry=dict(extensions=None, position=-1,),)
    outputs = GrayscaleModelMaker.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Resample


def test_Resample_inputs():
    input_map = dict(
        in_file=dict(extensions=None, mandatory=True,),
        interp=dict(mandatory=True, usedefault=True,),
        vox_size=dict(),
    )
    inputs = Resample.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Resample_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Resample.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Resample


def test_Resample_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-i %s", extensions=None, mandatory=True, position=-2,),
        resampled_file=dict(
            argstr="-o %s", extensions=None, genfile=True, position=-1,
        ),
        subjects_dir=dict(),
        voxel_size=dict(argstr="-vs %.2f %.2f %.2f", mandatory=True,),
    )
    inputs = Resample.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Resample_outputs():
    output_map = dict(resampled_file=dict(extensions=None,),)
    outputs = Resample.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import LabelGeometry


def test_LabelGeometry_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        dimension=dict(argstr="%d", position=0, usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        intensity_image=dict(
            argstr="%s", extensions=None, mandatory=True, position=2, usedefault=True,
        ),
        label_image=dict(argstr="%s", extensions=None, mandatory=True, position=1,),
        num_threads=dict(nohash=True, usedefault=True,),
        output_file=dict(
            argstr="%s",
            name_source=["label_image"],
            name_template="%s.csv",
            position=3,
        ),
    )
    inputs = LabelGeometry.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_LabelGeometry_outputs():
    output_map = dict(output_file=dict(extensions=None,),)
    outputs = LabelGeometry.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brains import BRAINSMush


def test_BRAINSMush_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        boundingBoxSize=dict(argstr="--boundingBoxSize %s", sep=",",),
        boundingBoxStart=dict(argstr="--boundingBoxStart %s", sep=",",),
        desiredMean=dict(argstr="--desiredMean %f",),
        desiredVariance=dict(argstr="--desiredVariance %f",),
        environ=dict(nohash=True, usedefault=True,),
        inputFirstVolume=dict(argstr="--inputFirstVolume %s", extensions=None,),
        inputMaskVolume=dict(argstr="--inputMaskVolume %s", extensions=None,),
        inputSecondVolume=dict(argstr="--inputSecondVolume %s", extensions=None,),
        lowerThresholdFactor=dict(argstr="--lowerThresholdFactor %f",),
        lowerThresholdFactorPre=dict(argstr="--lowerThresholdFactorPre %f",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputMask=dict(argstr="--outputMask %s", hash_files=False,),
        outputVolume=dict(argstr="--outputVolume %s", hash_files=False,),
        outputWeightsFile=dict(argstr="--outputWeightsFile %s", hash_files=False,),
        seed=dict(argstr="--seed %s", sep=",",),
        upperThresholdFactor=dict(argstr="--upperThresholdFactor %f",),
        upperThresholdFactorPre=dict(argstr="--upperThresholdFactorPre %f",),
    )
    inputs = BRAINSMush.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSMush_outputs():
    output_map = dict(
        outputMask=dict(extensions=None,),
        outputVolume=dict(extensions=None,),
        outputWeightsFile=dict(extensions=None,),
    )
    outputs = BRAINSMush.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import Deconvolve


def test_Deconvolve_inputs():
    input_map = dict(
        STATmask=dict(argstr="-STATmask %s", extensions=None,),
        TR_1D=dict(argstr="-TR_1D %f",),
        allzero_OK=dict(argstr="-allzero_OK",),
        args=dict(argstr="%s",),
        automask=dict(argstr="-automask",),
        cbucket=dict(argstr="-cbucket %s",),
        censor=dict(argstr="-censor %s", extensions=None,),
        dmbase=dict(argstr="-dmbase",),
        dname=dict(argstr="-D%s=%s",),
        environ=dict(nohash=True, usedefault=True,),
        force_TR=dict(argstr="-force_TR %f", position=0,),
        fout=dict(argstr="-fout",),
        global_times=dict(argstr="-global_times", xor=["local_times"],),
        glt_label=dict(argstr="-glt_label %d %s...", position=-1, requires=["gltsym"],),
        gltsym=dict(argstr="-gltsym 'SYM: %s'...", position=-2,),
        goforit=dict(argstr="-GOFORIT %i",),
        in_files=dict(argstr="-input %s", copyfile=False, position=1, sep=" ",),
        input1D=dict(argstr="-input1D %s", extensions=None,),
        legendre=dict(argstr="-legendre",),
        local_times=dict(argstr="-local_times", xor=["global_times"],),
        mask=dict(argstr="-mask %s", extensions=None,),
        noblock=dict(argstr="-noblock",),
        nocond=dict(argstr="-nocond",),
        nodmbase=dict(argstr="-nodmbase",),
        nofdr=dict(argstr="-noFDR",),
        nolegendre=dict(argstr="-nolegendre",),
        nosvd=dict(argstr="-nosvd",),
        num_glt=dict(argstr="-num_glt %d", position=-3,),
        num_stimts=dict(argstr="-num_stimts %d", position=-6,),
        num_threads=dict(argstr="-jobs %d", nohash=True,),
        ortvec=dict(argstr="-ortvec %s %s",),
        out_file=dict(argstr="-bucket %s", extensions=None,),
        outputtype=dict(),
        polort=dict(argstr="-polort %d",),
        rmsmin=dict(argstr="-rmsmin %f",),
        rout=dict(argstr="-rout",),
        sat=dict(argstr="-sat", xor=["trans"],),
        singvals=dict(argstr="-singvals",),
        stim_label=dict(
            argstr="-stim_label %d %s...", position=-4, requires=["stim_times"],
        ),
        stim_times=dict(argstr="-stim_times %d %s '%s'...", position=-5,),
        stim_times_subtract=dict(argstr="-stim_times_subtract %f",),
        svd=dict(argstr="-svd",),
        tout=dict(argstr="-tout",),
        trans=dict(argstr="-trans", xor=["sat"],),
        vout=dict(argstr="-vout",),
        x1D=dict(argstr="-x1D %s", extensions=None,),
        x1D_stop=dict(argstr="-x1D_stop",),
    )
    inputs = Deconvolve.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Deconvolve_outputs():
    output_map = dict(
        cbucket=dict(extensions=None,),
        out_file=dict(extensions=None,),
        reml_script=dict(extensions=None,),
        x1D=dict(extensions=None,),
    )
    outputs = Deconvolve.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..reg import RegAladin


def test_RegAladin_inputs():
    input_map = dict(
        aff_direct_flag=dict(argstr="-affDirect",),
        aff_file=dict(
            argstr="-aff %s",
            extensions=None,
            name_source=["flo_file"],
            name_template="%s_aff.txt",
        ),
        args=dict(argstr="%s",),
        cog_flag=dict(argstr="-cog",),
        environ=dict(nohash=True, usedefault=True,),
        flo_file=dict(argstr="-flo %s", extensions=None, mandatory=True,),
        flo_low_val=dict(argstr="-floLowThr %f",),
        flo_up_val=dict(argstr="-floUpThr %f",),
        fmask_file=dict(argstr="-fmask %s", extensions=None,),
        gpuid_val=dict(argstr="-gpuid %i",),
        i_val=dict(argstr="-pi %d",),
        in_aff_file=dict(argstr="-inaff %s", extensions=None,),
        ln_val=dict(argstr="-ln %d",),
        lp_val=dict(argstr="-lp %d",),
        maxit_val=dict(argstr="-maxit %d",),
        nac_flag=dict(argstr="-nac",),
        nosym_flag=dict(argstr="-noSym",),
        omp_core_val=dict(argstr="-omp %i", usedefault=True,),
        platform_val=dict(argstr="-platf %i",),
        ref_file=dict(argstr="-ref %s", extensions=None, mandatory=True,),
        ref_low_val=dict(argstr="-refLowThr %f",),
        ref_up_val=dict(argstr="-refUpThr %f",),
        res_file=dict(
            argstr="-res %s",
            extensions=None,
            name_source=["flo_file"],
            name_template="%s_res.nii.gz",
        ),
        rig_only_flag=dict(argstr="-rigOnly",),
        rmask_file=dict(argstr="-rmask %s", extensions=None,),
        smoo_f_val=dict(argstr="-smooF %f",),
        smoo_r_val=dict(argstr="-smooR %f",),
        v_val=dict(argstr="-pv %d",),
        verbosity_off_flag=dict(argstr="-voff",),
    )
    inputs = RegAladin.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_RegAladin_outputs():
    output_map = dict(
        aff_file=dict(extensions=None,),
        avg_output=dict(),
        res_file=dict(extensions=None,),
    )
    outputs = RegAladin.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import Label2Vol


def test_Label2Vol_inputs():
    input_map = dict(
        annot_file=dict(
            argstr="--annot %s",
            copyfile=False,
            extensions=None,
            mandatory=True,
            requires=("subject_id", "hemi"),
            xor=("label_file", "annot_file", "seg_file", "aparc_aseg"),
        ),
        aparc_aseg=dict(
            argstr="--aparc+aseg",
            mandatory=True,
            xor=("label_file", "annot_file", "seg_file", "aparc_aseg"),
        ),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        fill_thresh=dict(argstr="--fillthresh %g",),
        hemi=dict(argstr="--hemi %s",),
        identity=dict(argstr="--identity", xor=("reg_file", "reg_header", "identity"),),
        invert_mtx=dict(argstr="--invertmtx",),
        label_file=dict(
            argstr="--label %s...",
            copyfile=False,
            mandatory=True,
            xor=("label_file", "annot_file", "seg_file", "aparc_aseg"),
        ),
        label_hit_file=dict(argstr="--hits %s", extensions=None,),
        label_voxel_volume=dict(argstr="--labvoxvol %f",),
        map_label_stat=dict(argstr="--label-stat %s", extensions=None,),
        native_vox2ras=dict(argstr="--native-vox2ras",),
        proj=dict(argstr="--proj %s %f %f %f", requires=("subject_id", "hemi"),),
        reg_file=dict(
            argstr="--reg %s",
            extensions=None,
            xor=("reg_file", "reg_header", "identity"),
        ),
        reg_header=dict(
            argstr="--regheader %s",
            extensions=None,
            xor=("reg_file", "reg_header", "identity"),
        ),
        seg_file=dict(
            argstr="--seg %s",
            copyfile=False,
            extensions=None,
            mandatory=True,
            xor=("label_file", "annot_file", "seg_file", "aparc_aseg"),
        ),
        subject_id=dict(argstr="--subject %s",),
        subjects_dir=dict(),
        surface=dict(argstr="--surf %s",),
        template_file=dict(argstr="--temp %s", extensions=None, mandatory=True,),
        vol_label_file=dict(argstr="--o %s", extensions=None, genfile=True,),
    )
    inputs = Label2Vol.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Label2Vol_outputs():
    output_map = dict(vol_label_file=dict(extensions=None,),)
    outputs = Label2Vol.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brainsuite import Skullfinder


def test_Skullfinder_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bgLabelValue=dict(argstr="--bglabel %d",),
        brainLabelValue=dict(argstr="--brainlabel %d",),
        environ=dict(nohash=True, usedefault=True,),
        inputMRIFile=dict(argstr="-i %s", extensions=None, mandatory=True,),
        inputMaskFile=dict(argstr="-m %s", extensions=None, mandatory=True,),
        lowerThreshold=dict(argstr="-l %d",),
        outputLabelFile=dict(argstr="-o %s", extensions=None, genfile=True,),
        performFinalOpening=dict(argstr="--finalOpening",),
        scalpLabelValue=dict(argstr="--scalplabel %d",),
        skullLabelValue=dict(argstr="--skulllabel %d",),
        spaceLabelValue=dict(argstr="--spacelabel %d",),
        surfaceFilePrefix=dict(argstr="-s %s",),
        upperThreshold=dict(argstr="-u %d",),
        verbosity=dict(argstr="-v %d",),
    )
    inputs = Skullfinder.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Skullfinder_outputs():
    output_map = dict(outputLabelFile=dict(extensions=None,),)
    outputs = Skullfinder.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..simpleregiongrowingsegmentation import SimpleRegionGrowingSegmentation


def test_SimpleRegionGrowingSegmentation_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputVolume=dict(argstr="%s", extensions=None, position=-2,),
        iterations=dict(argstr="--iterations %d",),
        labelvalue=dict(argstr="--labelvalue %d",),
        multiplier=dict(argstr="--multiplier %f",),
        neighborhood=dict(argstr="--neighborhood %d",),
        outputVolume=dict(argstr="%s", hash_files=False, position=-1,),
        seed=dict(argstr="--seed %s...",),
        smoothingIterations=dict(argstr="--smoothingIterations %d",),
        timestep=dict(argstr="--timestep %f",),
    )
    inputs = SimpleRegionGrowingSegmentation.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SimpleRegionGrowingSegmentation_outputs():
    output_map = dict(outputVolume=dict(extensions=None, position=-1,),)
    outputs = SimpleRegionGrowingSegmentation.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..fiberprocess import fiberprocess


def test_fiberprocess_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        displacement_field=dict(argstr="--displacement_field %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        fiber_file=dict(argstr="--fiber_file %s", extensions=None,),
        fiber_output=dict(argstr="--fiber_output %s", hash_files=False,),
        fiber_radius=dict(argstr="--fiber_radius %f",),
        h_field=dict(argstr="--h_field %s", extensions=None,),
        index_space=dict(argstr="--index_space ",),
        noDataChange=dict(argstr="--noDataChange ",),
        no_warp=dict(argstr="--no_warp ",),
        saveProperties=dict(argstr="--saveProperties ",),
        tensor_volume=dict(argstr="--tensor_volume %s", extensions=None,),
        verbose=dict(argstr="--verbose ",),
        voxel_label=dict(argstr="--voxel_label %d",),
        voxelize=dict(argstr="--voxelize %s", hash_files=False,),
        voxelize_count_fibers=dict(argstr="--voxelize_count_fibers ",),
    )
    inputs = fiberprocess.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_fiberprocess_outputs():
    output_map = dict(
        fiber_output=dict(extensions=None,), voxelize=dict(extensions=None,),
    )
    outputs = fiberprocess.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..featuredetection import DumpBinaryTrainingVectors


def test_DumpBinaryTrainingVectors_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputHeaderFilename=dict(argstr="--inputHeaderFilename %s", extensions=None,),
        inputVectorFilename=dict(argstr="--inputVectorFilename %s", extensions=None,),
    )
    inputs = DumpBinaryTrainingVectors.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DumpBinaryTrainingVectors_outputs():
    output_map = dict()
    outputs = DumpBinaryTrainingVectors.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brains import BRAINSAlignMSP


def test_BRAINSAlignMSP_inputs():
    input_map = dict(
        BackgroundFillValue=dict(argstr="--BackgroundFillValue %s",),
        OutputresampleMSP=dict(argstr="--OutputresampleMSP %s", hash_files=False,),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputVolume=dict(argstr="--inputVolume %s", extensions=None,),
        interpolationMode=dict(argstr="--interpolationMode %s",),
        mspQualityLevel=dict(argstr="--mspQualityLevel %d",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        rescaleIntensities=dict(argstr="--rescaleIntensities ",),
        rescaleIntensitiesOutputRange=dict(
            argstr="--rescaleIntensitiesOutputRange %s", sep=",",
        ),
        resultsDir=dict(argstr="--resultsDir %s", hash_files=False,),
        trimRescaledIntensities=dict(argstr="--trimRescaledIntensities %f",),
        verbose=dict(argstr="--verbose ",),
        writedebuggingImagesLevel=dict(argstr="--writedebuggingImagesLevel %d",),
    )
    inputs = BRAINSAlignMSP.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSAlignMSP_outputs():
    output_map = dict(OutputresampleMSP=dict(extensions=None,), resultsDir=dict(),)
    outputs = BRAINSAlignMSP.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import MRIsCALabel


def test_MRIsCALabel_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        aseg=dict(argstr="-aseg %s", extensions=None,),
        canonsurf=dict(argstr="%s", extensions=None, mandatory=True, position=-3,),
        classifier=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        copy_inputs=dict(),
        curv=dict(extensions=None, mandatory=True,),
        environ=dict(nohash=True, usedefault=True,),
        hemisphere=dict(argstr="%s", mandatory=True, position=-4,),
        label=dict(argstr="-l %s", extensions=None,),
        num_threads=dict(),
        out_file=dict(
            argstr="%s",
            extensions=None,
            hash_files=False,
            keep_extension=True,
            name_source=["hemisphere"],
            name_template="%s.aparc.annot",
            position=-1,
        ),
        seed=dict(argstr="-seed %d",),
        smoothwm=dict(extensions=None, mandatory=True,),
        subject_id=dict(argstr="%s", mandatory=True, position=-5, usedefault=True,),
        subjects_dir=dict(),
        sulc=dict(extensions=None, mandatory=True,),
    )
    inputs = MRIsCALabel.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MRIsCALabel_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = MRIsCALabel.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..fix import FeatureExtractor


def test_FeatureExtractor_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        mel_ica=dict(argstr="%s", copyfile=False, position=-1,),
    )
    inputs = FeatureExtractor.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FeatureExtractor_outputs():
    output_map = dict(mel_ica=dict(argstr="%s", copyfile=False, position=-1,),)
    outputs = FeatureExtractor.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..developer import JistCortexSurfaceMeshInflation


def test_JistCortexSurfaceMeshInflation_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inLevelset=dict(argstr="--inLevelset %s", extensions=None,),
        inLorentzian=dict(argstr="--inLorentzian %s",),
        inMax=dict(argstr="--inMax %d",),
        inMean=dict(argstr="--inMean %f",),
        inSOR=dict(argstr="--inSOR %f",),
        inStep=dict(argstr="--inStep %d",),
        inTopology=dict(argstr="--inTopology %s",),
        null=dict(argstr="--null %s",),
        outInflated=dict(argstr="--outInflated %s", hash_files=False,),
        outOriginal=dict(argstr="--outOriginal %s", hash_files=False,),
        xDefaultMem=dict(argstr="-xDefaultMem %d",),
        xMaxProcess=dict(argstr="-xMaxProcess %d", usedefault=True,),
        xPrefExt=dict(argstr="--xPrefExt %s",),
    )
    inputs = JistCortexSurfaceMeshInflation.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_JistCortexSurfaceMeshInflation_outputs():
    output_map = dict(
        outInflated=dict(extensions=None,), outOriginal=dict(extensions=None,),
    )
    outputs = JistCortexSurfaceMeshInflation.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import QwarpPlusMinus


def test_QwarpPlusMinus_inputs():
    input_map = dict(
        Qfinal=dict(argstr="-Qfinal",),
        Qonly=dict(argstr="-Qonly",),
        allineate=dict(argstr="-allineate",),
        allineate_opts=dict(argstr="-allineate_opts %s", requires=["allineate"],),
        allsave=dict(argstr="-allsave", xor=["nopadWARP", "duplo", "plusminus"],),
        args=dict(argstr="%s",),
        ballopt=dict(argstr="-ballopt", xor=["workhard", "boxopt"],),
        base_file=dict(
            argstr="-base %s", copyfile=False, extensions=None, mandatory=True,
        ),
        baxopt=dict(argstr="-boxopt", xor=["workhard", "ballopt"],),
        blur=dict(argstr="-blur %s",),
        duplo=dict(
            argstr="-duplo",
            xor=["gridlist", "maxlev", "inilev", "iniwarp", "plusminus", "allsave"],
        ),
        emask=dict(argstr="-emask %s", copyfile=False, extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        expad=dict(argstr="-expad %d", xor=["nopadWARP"],),
        gridlist=dict(
            argstr="-gridlist %s",
            copyfile=False,
            extensions=None,
            xor=["duplo", "plusminus"],
        ),
        hel=dict(argstr="-hel", xor=["nmi", "mi", "lpc", "lpa", "pear"],),
        in_file=dict(
            argstr="-source %s", copyfile=False, extensions=None, mandatory=True,
        ),
        inilev=dict(argstr="-inilev %d", xor=["duplo"],),
        iniwarp=dict(argstr="-iniwarp %s", xor=["duplo"],),
        iwarp=dict(argstr="-iwarp", xor=["plusminus"],),
        lpa=dict(argstr="-lpa", xor=["nmi", "mi", "lpc", "hel", "pear"],),
        lpc=dict(argstr="-lpc", position=-2, xor=["nmi", "mi", "hel", "lpa", "pear"],),
        maxlev=dict(argstr="-maxlev %d", position=-1, xor=["duplo"],),
        mi=dict(argstr="-mi", xor=["mi", "hel", "lpc", "lpa", "pear"],),
        minpatch=dict(argstr="-minpatch %d",),
        nmi=dict(argstr="-nmi", xor=["nmi", "hel", "lpc", "lpa", "pear"],),
        noXdis=dict(argstr="-noXdis",),
        noYdis=dict(argstr="-noYdis",),
        noZdis=dict(argstr="-noZdis",),
        noneg=dict(argstr="-noneg",),
        nopad=dict(argstr="-nopad",),
        nopadWARP=dict(argstr="-nopadWARP", xor=["allsave", "expad"],),
        nopenalty=dict(argstr="-nopenalty",),
        nowarp=dict(argstr="-nowarp",),
        noweight=dict(argstr="-noweight",),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(
            argstr="-prefix %s", extensions=None, position=0, usedefault=True,
        ),
        out_weight_file=dict(argstr="-wtprefix %s", extensions=None,),
        outputtype=dict(),
        overwrite=dict(argstr="-overwrite",),
        pblur=dict(argstr="-pblur %s",),
        pear=dict(argstr="-pear",),
        penfac=dict(argstr="-penfac %f",),
        plusminus=dict(
            argstr="-plusminus",
            position=1,
            usedefault=True,
            xor=["duplo", "allsave", "iwarp"],
        ),
        quiet=dict(argstr="-quiet", xor=["verb"],),
        resample=dict(argstr="-resample",),
        source_file=dict(
            argstr="-source %s",
            copyfile=False,
            deprecated="1.1.2",
            extensions=None,
            new_name="in_file",
        ),
        verb=dict(argstr="-verb", xor=["quiet"],),
        wball=dict(argstr="-wball %s", xor=["wmask"],),
        weight=dict(argstr="-weight %s", extensions=None,),
        wmask=dict(argstr="-wpass %s %f", xor=["wball"],),
        workhard=dict(argstr="-workhard", xor=["boxopt", "ballopt"],),
    )
    inputs = QwarpPlusMinus.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_QwarpPlusMinus_outputs():
    output_map = dict(
        base_warp=dict(extensions=None,),
        source_warp=dict(extensions=None,),
        warped_base=dict(extensions=None,),
        warped_source=dict(extensions=None,),
        weights=dict(extensions=None,),
    )
    outputs = QwarpPlusMinus.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..converters import DicomToNrrdConverter


def test_DicomToNrrdConverter_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputDicomDirectory=dict(argstr="--inputDicomDirectory %s",),
        outputDirectory=dict(argstr="--outputDirectory %s", hash_files=False,),
        outputVolume=dict(argstr="--outputVolume %s",),
        smallGradientThreshold=dict(argstr="--smallGradientThreshold %f",),
        useBMatrixGradientDirections=dict(argstr="--useBMatrixGradientDirections ",),
        useIdentityMeaseurementFrame=dict(argstr="--useIdentityMeaseurementFrame ",),
        writeProtocolGradientsFile=dict(argstr="--writeProtocolGradientsFile ",),
    )
    inputs = DicomToNrrdConverter.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DicomToNrrdConverter_outputs():
    output_map = dict(outputDirectory=dict(),)
    outputs = DicomToNrrdConverter.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dti import DistanceMap


def test_DistanceMap_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        distance_map=dict(
            argstr="--out=%s", extensions=None, genfile=True, hash_files=False,
        ),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="--in=%s", extensions=None, mandatory=True,),
        invert_input=dict(argstr="--invert",),
        local_max_file=dict(argstr="--localmax=%s", hash_files=False,),
        mask_file=dict(argstr="--mask=%s", extensions=None,),
        output_type=dict(),
    )
    inputs = DistanceMap.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DistanceMap_outputs():
    output_map = dict(
        distance_map=dict(extensions=None,), local_max_file=dict(extensions=None,),
    )
    outputs = DistanceMap.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import FLAMEO


def test_FLAMEO_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        burnin=dict(argstr="--burnin=%d",),
        cope_file=dict(argstr="--copefile=%s", extensions=None, mandatory=True,),
        cov_split_file=dict(
            argstr="--covsplitfile=%s", extensions=None, mandatory=True,
        ),
        design_file=dict(argstr="--designfile=%s", extensions=None, mandatory=True,),
        dof_var_cope_file=dict(argstr="--dofvarcopefile=%s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        f_con_file=dict(argstr="--fcontrastsfile=%s", extensions=None,),
        fix_mean=dict(argstr="--fixmean",),
        infer_outliers=dict(argstr="--inferoutliers",),
        log_dir=dict(argstr="--ld=%s", usedefault=True,),
        mask_file=dict(argstr="--maskfile=%s", extensions=None, mandatory=True,),
        n_jumps=dict(argstr="--njumps=%d",),
        no_pe_outputs=dict(argstr="--nopeoutput",),
        outlier_iter=dict(argstr="--ioni=%d",),
        output_type=dict(),
        run_mode=dict(argstr="--runmode=%s", mandatory=True,),
        sample_every=dict(argstr="--sampleevery=%d",),
        sigma_dofs=dict(argstr="--sigma_dofs=%d",),
        t_con_file=dict(argstr="--tcontrastsfile=%s", extensions=None, mandatory=True,),
        var_cope_file=dict(argstr="--varcopefile=%s", extensions=None,),
    )
    inputs = FLAMEO.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FLAMEO_outputs():
    output_map = dict(
        copes=dict(),
        fstats=dict(),
        mrefvars=dict(),
        pes=dict(),
        res4d=dict(),
        stats_dir=dict(),
        tdof=dict(),
        tstats=dict(),
        var_copes=dict(),
        weights=dict(),
        zfstats=dict(),
        zstats=dict(),
    )
    outputs = FLAMEO.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brainsuite import Hemisplit


def test_Hemisplit_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputHemisphereLabelFile=dict(argstr="-l %s", extensions=None, mandatory=True,),
        inputSurfaceFile=dict(argstr="-i %s", extensions=None, mandatory=True,),
        outputLeftHemisphere=dict(argstr="--left %s", extensions=None, genfile=True,),
        outputLeftPialHemisphere=dict(argstr="-pl %s", extensions=None, genfile=True,),
        outputRightHemisphere=dict(argstr="--right %s", extensions=None, genfile=True,),
        outputRightPialHemisphere=dict(argstr="-pr %s", extensions=None, genfile=True,),
        pialSurfaceFile=dict(argstr="-p %s", extensions=None,),
        timer=dict(argstr="--timer",),
        verbosity=dict(argstr="-v %d",),
    )
    inputs = Hemisplit.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Hemisplit_outputs():
    output_map = dict(
        outputLeftHemisphere=dict(extensions=None,),
        outputLeftPialHemisphere=dict(extensions=None,),
        outputRightHemisphere=dict(extensions=None,),
        outputRightPialHemisphere=dict(extensions=None,),
    )
    outputs = Hemisplit.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..developer import MedicAlgorithmN3


def test_MedicAlgorithmN3_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inAutomatic=dict(argstr="--inAutomatic %s",),
        inEnd=dict(argstr="--inEnd %f",),
        inField=dict(argstr="--inField %f",),
        inInput=dict(argstr="--inInput %s", extensions=None,),
        inKernel=dict(argstr="--inKernel %f",),
        inMaximum=dict(argstr="--inMaximum %d",),
        inSignal=dict(argstr="--inSignal %f",),
        inSubsample=dict(argstr="--inSubsample %f",),
        inWeiner=dict(argstr="--inWeiner %f",),
        null=dict(argstr="--null %s",),
        outInhomogeneity=dict(argstr="--outInhomogeneity %s", hash_files=False,),
        outInhomogeneity2=dict(argstr="--outInhomogeneity2 %s", hash_files=False,),
        xDefaultMem=dict(argstr="-xDefaultMem %d",),
        xMaxProcess=dict(argstr="-xMaxProcess %d", usedefault=True,),
        xPrefExt=dict(argstr="--xPrefExt %s",),
    )
    inputs = MedicAlgorithmN3.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MedicAlgorithmN3_outputs():
    output_map = dict(
        outInhomogeneity=dict(extensions=None,),
        outInhomogeneity2=dict(extensions=None,),
    )
    outputs = MedicAlgorithmN3.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import EditTransform


def test_EditTransform_inputs():
    input_map = dict(
        interpolation=dict(argstr="FinalBSplineInterpolationOrder", usedefault=True,),
        output_file=dict(extensions=None,),
        output_format=dict(argstr="ResultImageFormat",),
        output_type=dict(argstr="ResultImagePixelType",),
        reference_image=dict(extensions=None,),
        transform_file=dict(extensions=None, mandatory=True,),
    )
    inputs = EditTransform.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_EditTransform_outputs():
    output_map = dict(output_file=dict(extensions=None,),)
    outputs = EditTransform.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Merge


def test_Merge_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        dimension=dict(argstr="-%s", mandatory=True, position=0,),
        environ=dict(nohash=True, usedefault=True,),
        in_files=dict(argstr="%s", mandatory=True, position=2,),
        merged_file=dict(
            argstr="%s",
            extensions=None,
            hash_files=False,
            name_source="in_files",
            name_template="%s_merged",
            position=1,
        ),
        output_type=dict(),
        tr=dict(argstr="%.2f", position=-1,),
    )
    inputs = Merge.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Merge_outputs():
    output_map = dict(merged_file=dict(extensions=None,),)
    outputs = Merge.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..legacy import antsIntroduction


def test_antsIntroduction_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bias_field_correction=dict(argstr="-n 1",),
        dimension=dict(argstr="-d %d", position=1, usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        force_proceed=dict(argstr="-f 1",),
        input_image=dict(
            argstr="-i %s", copyfile=False, extensions=None, mandatory=True,
        ),
        inverse_warp_template_labels=dict(argstr="-l",),
        max_iterations=dict(argstr="-m %s", sep="x",),
        num_threads=dict(nohash=True, usedefault=True,),
        out_prefix=dict(argstr="-o %s", usedefault=True,),
        quality_check=dict(argstr="-q 1",),
        reference_image=dict(
            argstr="-r %s", copyfile=True, extensions=None, mandatory=True,
        ),
        similarity_metric=dict(argstr="-s %s",),
        transformation_model=dict(argstr="-t %s", usedefault=True,),
    )
    inputs = antsIntroduction.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_antsIntroduction_outputs():
    output_map = dict(
        affine_transformation=dict(extensions=None,),
        input_file=dict(extensions=None,),
        inverse_warp_field=dict(extensions=None,),
        output_file=dict(extensions=None,),
        warp_field=dict(extensions=None,),
    )
    outputs = antsIntroduction.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..gtract import gtractInvertBSplineTransform


def test_gtractInvertBSplineTransform_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputReferenceVolume=dict(argstr="--inputReferenceVolume %s", extensions=None,),
        inputTransform=dict(argstr="--inputTransform %s", extensions=None,),
        landmarkDensity=dict(argstr="--landmarkDensity %s", sep=",",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputTransform=dict(argstr="--outputTransform %s", hash_files=False,),
    )
    inputs = gtractInvertBSplineTransform.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_gtractInvertBSplineTransform_outputs():
    output_map = dict(outputTransform=dict(extensions=None,),)
    outputs = gtractInvertBSplineTransform.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Dot


def test_Dot_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        demean=dict(argstr="-demean",),
        docoef=dict(argstr="-docoef",),
        docor=dict(argstr="-docor",),
        dodice=dict(argstr="-dodice",),
        dodot=dict(argstr="-dodot",),
        doeta2=dict(argstr="-doeta2",),
        dosums=dict(argstr="-dosums",),
        environ=dict(nohash=True, usedefault=True,),
        full=dict(argstr="-full",),
        in_files=dict(argstr="%s ...", position=-2,),
        mask=dict(argstr="-mask %s", extensions=None,),
        mrange=dict(argstr="-mrange %s %s",),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(argstr=" |& tee %s", extensions=None, position=-1,),
        outputtype=dict(),
        show_labels=dict(argstr="-show_labels",),
        upper=dict(argstr="-upper",),
    )
    inputs = Dot.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Dot_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Dot.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..registration import Register


def test_Register_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        curv=dict(argstr="-curv", requires=["in_smoothwm"],),
        environ=dict(nohash=True, usedefault=True,),
        in_smoothwm=dict(copyfile=True, extensions=None,),
        in_sulc=dict(copyfile=True, extensions=None, mandatory=True,),
        in_surf=dict(
            argstr="%s", copyfile=True, extensions=None, mandatory=True, position=-3,
        ),
        out_file=dict(argstr="%s", extensions=None, genfile=True, position=-1,),
        subjects_dir=dict(),
        target=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
    )
    inputs = Register.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Register_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Register.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import SmoothEstimate


def test_SmoothEstimate_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        dof=dict(argstr="--dof=%d", mandatory=True, xor=["zstat_file"],),
        environ=dict(nohash=True, usedefault=True,),
        mask_file=dict(argstr="--mask=%s", extensions=None, mandatory=True,),
        output_type=dict(),
        residual_fit_file=dict(argstr="--res=%s", extensions=None, requires=["dof"],),
        zstat_file=dict(argstr="--zstat=%s", extensions=None, xor=["dof"],),
    )
    inputs = SmoothEstimate.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SmoothEstimate_outputs():
    output_map = dict(dlh=dict(), resels=dict(), volume=dict(),)
    outputs = SmoothEstimate.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brainsuite import Cerebro


def test_Cerebro_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        costFunction=dict(argstr="-c %d", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        inputAtlasLabelFile=dict(
            argstr="--atlaslabels %s", extensions=None, mandatory=True,
        ),
        inputAtlasMRIFile=dict(argstr="--atlas %s", extensions=None, mandatory=True,),
        inputBrainMaskFile=dict(argstr="-m %s", extensions=None,),
        inputMRIFile=dict(argstr="-i %s", extensions=None, mandatory=True,),
        keepTempFiles=dict(argstr="--keep",),
        linearConvergence=dict(argstr="--linconv %f",),
        outputAffineTransformFile=dict(
            argstr="--air %s", extensions=None, genfile=True,
        ),
        outputCerebrumMaskFile=dict(argstr="-o %s", extensions=None, genfile=True,),
        outputLabelVolumeFile=dict(argstr="-l %s", extensions=None, genfile=True,),
        outputWarpTransformFile=dict(
            argstr="--warp %s", extensions=None, genfile=True,
        ),
        tempDirectory=dict(argstr="--tempdir %s",),
        tempDirectoryBase=dict(argstr="--tempdirbase %s",),
        useCentroids=dict(argstr="--centroids",),
        verbosity=dict(argstr="-v %d",),
        warpConvergence=dict(argstr="--warpconv %f",),
        warpLabel=dict(argstr="--warplevel %d",),
    )
    inputs = Cerebro.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Cerebro_outputs():
    output_map = dict(
        outputAffineTransformFile=dict(extensions=None,),
        outputCerebrumMaskFile=dict(extensions=None,),
        outputLabelVolumeFile=dict(extensions=None,),
        outputWarpTransformFile=dict(extensions=None,),
    )
    outputs = Cerebro.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..convert import ProcStreamlines


def test_ProcStreamlines_inputs():
    input_map = dict(
        allowmultitargets=dict(argstr="-allowmultitargets",),
        args=dict(argstr="%s",),
        datadims=dict(argstr="-datadims %s", units="voxels",),
        directional=dict(argstr="-directional %s", units="NA",),
        discardloops=dict(argstr="-discardloops",),
        endpointfile=dict(argstr="-endpointfile %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        exclusionfile=dict(argstr="-exclusionfile %s", extensions=None,),
        gzip=dict(argstr="-gzip",),
        in_file=dict(
            argstr="-inputfile %s", extensions=None, mandatory=True, position=1,
        ),
        inputmodel=dict(argstr="-inputmodel %s", usedefault=True,),
        iterations=dict(argstr="-iterations %d", units="NA",),
        maxtractlength=dict(argstr="-maxtractlength %d", units="mm",),
        maxtractpoints=dict(argstr="-maxtractpoints %d", units="NA",),
        mintractlength=dict(argstr="-mintractlength %d", units="mm",),
        mintractpoints=dict(argstr="-mintractpoints %d", units="NA",),
        noresample=dict(argstr="-noresample",),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        outputacm=dict(argstr="-outputacm", requires=["outputroot", "seedfile"],),
        outputcbs=dict(
            argstr="-outputcbs", requires=["outputroot", "targetfile", "seedfile"],
        ),
        outputcp=dict(argstr="-outputcp", requires=["outputroot", "seedfile"],),
        outputroot=dict(argstr="-outputroot %s", extensions=None,),
        outputsc=dict(argstr="-outputsc", requires=["outputroot", "seedfile"],),
        outputtracts=dict(argstr="-outputtracts",),
        regionindex=dict(argstr="-regionindex %d", units="mm",),
        resamplestepsize=dict(argstr="-resamplestepsize %d", units="NA",),
        seedfile=dict(argstr="-seedfile %s", extensions=None,),
        seedpointmm=dict(argstr="-seedpointmm %s", units="mm",),
        seedpointvox=dict(argstr="-seedpointvox %s", units="voxels",),
        targetfile=dict(argstr="-targetfile %s", extensions=None,),
        truncateinexclusion=dict(argstr="-truncateinexclusion",),
        truncateloops=dict(argstr="-truncateloops",),
        voxeldims=dict(argstr="-voxeldims %s", units="mm",),
        waypointfile=dict(argstr="-waypointfile %s", extensions=None,),
    )
    inputs = ProcStreamlines.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ProcStreamlines_outputs():
    output_map = dict(outputroot_files=dict(), proc=dict(extensions=None,),)
    outputs = ProcStreamlines.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..ukftractography import UKFTractography


def test_UKFTractography_inputs():
    input_map = dict(
        Ql=dict(argstr="--Ql %f",),
        Qm=dict(argstr="--Qm %f",),
        Qw=dict(argstr="--Qw %f",),
        Rs=dict(argstr="--Rs %f",),
        args=dict(argstr="%s",),
        dwiFile=dict(argstr="--dwiFile %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        freeWater=dict(argstr="--freeWater ",),
        fullTensorModel=dict(argstr="--fullTensorModel ",),
        labels=dict(argstr="--labels %s", sep=",",),
        maskFile=dict(argstr="--maskFile %s", extensions=None,),
        maxBranchingAngle=dict(argstr="--maxBranchingAngle %f",),
        maxHalfFiberLength=dict(argstr="--maxHalfFiberLength %f",),
        minBranchingAngle=dict(argstr="--minBranchingAngle %f",),
        minFA=dict(argstr="--minFA %f",),
        minGA=dict(argstr="--minGA %f",),
        numTensor=dict(argstr="--numTensor %s",),
        numThreads=dict(argstr="--numThreads %d",),
        recordCovariance=dict(argstr="--recordCovariance ",),
        recordFA=dict(argstr="--recordFA ",),
        recordFreeWater=dict(argstr="--recordFreeWater ",),
        recordLength=dict(argstr="--recordLength %f",),
        recordNMSE=dict(argstr="--recordNMSE ",),
        recordState=dict(argstr="--recordState ",),
        recordTensors=dict(argstr="--recordTensors ",),
        recordTrace=dict(argstr="--recordTrace ",),
        seedFALimit=dict(argstr="--seedFALimit %f",),
        seedsFile=dict(argstr="--seedsFile %s", extensions=None,),
        seedsPerVoxel=dict(argstr="--seedsPerVoxel %d",),
        stepLength=dict(argstr="--stepLength %f",),
        storeGlyphs=dict(argstr="--storeGlyphs ",),
        tracts=dict(argstr="--tracts %s", hash_files=False,),
        tractsWithSecondTensor=dict(
            argstr="--tractsWithSecondTensor %s", hash_files=False,
        ),
        writeAsciiTracts=dict(argstr="--writeAsciiTracts ",),
        writeUncompressedTracts=dict(argstr="--writeUncompressedTracts ",),
    )
    inputs = UKFTractography.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_UKFTractography_outputs():
    output_map = dict(
        tracts=dict(extensions=None,), tractsWithSecondTensor=dict(extensions=None,),
    )
    outputs = UKFTractography.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dti import DTIRecon


def test_DTIRecon_inputs():
    input_map = dict(
        DWI=dict(argstr="%s", extensions=None, mandatory=True, position=1,),
        args=dict(argstr="%s",),
        b0_threshold=dict(argstr="-b0_th",),
        bvals=dict(extensions=None, mandatory=True,),
        bvecs=dict(argstr="-gm %s", extensions=None, mandatory=True,),
        environ=dict(nohash=True, usedefault=True,),
        image_orientation_vectors=dict(argstr="-iop %f",),
        n_averages=dict(argstr="-nex %s",),
        oblique_correction=dict(argstr="-oc",),
        out_prefix=dict(argstr="%s", position=2, usedefault=True,),
        output_type=dict(argstr="-ot %s", usedefault=True,),
    )
    inputs = DTIRecon.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DTIRecon_outputs():
    output_map = dict(
        ADC=dict(extensions=None,),
        B0=dict(extensions=None,),
        FA=dict(extensions=None,),
        FA_color=dict(extensions=None,),
        L1=dict(extensions=None,),
        L2=dict(extensions=None,),
        L3=dict(extensions=None,),
        V1=dict(extensions=None,),
        V2=dict(extensions=None,),
        V3=dict(extensions=None,),
        exp=dict(extensions=None,),
        tensor=dict(extensions=None,),
    )
    outputs = DTIRecon.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import FLIRT


def test_FLIRT_inputs():
    input_map = dict(
        angle_rep=dict(argstr="-anglerep %s",),
        apply_isoxfm=dict(argstr="-applyisoxfm %f", xor=["apply_xfm"],),
        apply_xfm=dict(argstr="-applyxfm",),
        args=dict(argstr="%s",),
        bbrslope=dict(argstr="-bbrslope %f", min_ver="5.0.0",),
        bbrtype=dict(argstr="-bbrtype %s", min_ver="5.0.0",),
        bgvalue=dict(argstr="-setbackground %f",),
        bins=dict(argstr="-bins %d",),
        coarse_search=dict(argstr="-coarsesearch %d", units="degrees",),
        cost=dict(argstr="-cost %s",),
        cost_func=dict(argstr="-searchcost %s",),
        datatype=dict(argstr="-datatype %s",),
        display_init=dict(argstr="-displayinit",),
        dof=dict(argstr="-dof %d",),
        echospacing=dict(argstr="-echospacing %f", min_ver="5.0.0",),
        environ=dict(nohash=True, usedefault=True,),
        fieldmap=dict(argstr="-fieldmap %s", extensions=None, min_ver="5.0.0",),
        fieldmapmask=dict(argstr="-fieldmapmask %s", extensions=None, min_ver="5.0.0",),
        fine_search=dict(argstr="-finesearch %d", units="degrees",),
        force_scaling=dict(argstr="-forcescaling",),
        in_file=dict(argstr="-in %s", extensions=None, mandatory=True, position=0,),
        in_matrix_file=dict(argstr="-init %s", extensions=None,),
        in_weight=dict(argstr="-inweight %s", extensions=None,),
        interp=dict(argstr="-interp %s",),
        min_sampling=dict(argstr="-minsampling %f", units="mm",),
        no_clamp=dict(argstr="-noclamp",),
        no_resample=dict(argstr="-noresample",),
        no_resample_blur=dict(argstr="-noresampblur",),
        no_search=dict(argstr="-nosearch",),
        out_file=dict(
            argstr="-out %s",
            extensions=None,
            hash_files=False,
            name_source=["in_file"],
            name_template="%s_flirt",
            position=2,
        ),
        out_log=dict(
            extensions=None,
            keep_extension=True,
            name_source=["in_file"],
            name_template="%s_flirt.log",
            requires=["save_log"],
        ),
        out_matrix_file=dict(
            argstr="-omat %s",
            extensions=None,
            hash_files=False,
            keep_extension=True,
            name_source=["in_file"],
            name_template="%s_flirt.mat",
            position=3,
        ),
        output_type=dict(),
        padding_size=dict(argstr="-paddingsize %d", units="voxels",),
        pedir=dict(argstr="-pedir %d", min_ver="5.0.0",),
        ref_weight=dict(argstr="-refweight %s", extensions=None,),
        reference=dict(argstr="-ref %s", extensions=None, mandatory=True, position=1,),
        rigid2D=dict(argstr="-2D",),
        save_log=dict(),
        schedule=dict(argstr="-schedule %s", extensions=None,),
        searchr_x=dict(argstr="-searchrx %s", units="degrees",),
        searchr_y=dict(argstr="-searchry %s", units="degrees",),
        searchr_z=dict(argstr="-searchrz %s", units="degrees",),
        sinc_width=dict(argstr="-sincwidth %d", units="voxels",),
        sinc_window=dict(argstr="-sincwindow %s",),
        uses_qform=dict(argstr="-usesqform",),
        verbose=dict(argstr="-verbose %d",),
        wm_seg=dict(argstr="-wmseg %s", extensions=None, min_ver="5.0.0",),
        wmcoords=dict(argstr="-wmcoords %s", extensions=None, min_ver="5.0.0",),
        wmnorms=dict(argstr="-wmnorms %s", extensions=None, min_ver="5.0.0",),
    )
    inputs = FLIRT.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FLIRT_outputs():
    output_map = dict(
        out_file=dict(extensions=None,),
        out_log=dict(extensions=None,),
        out_matrix_file=dict(extensions=None,),
    )
    outputs = FLIRT.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..convert import Camino2Trackvis


def test_Camino2Trackvis_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        data_dims=dict(argstr="-d %s", mandatory=True, position=4, sep=",",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-i %s", extensions=None, mandatory=True, position=1,),
        min_length=dict(argstr="-l %d", position=3, units="mm",),
        nifti_file=dict(argstr="--nifti %s", extensions=None, position=7,),
        out_file=dict(argstr="-o %s", extensions=None, genfile=True, position=2,),
        voxel_dims=dict(argstr="-x %s", mandatory=True, position=5, sep=",",),
        voxel_order=dict(
            argstr="--voxel-order %s", extensions=None, mandatory=True, position=6,
        ),
    )
    inputs = Camino2Trackvis.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Camino2Trackvis_outputs():
    output_map = dict(trackvis=dict(extensions=None,),)
    outputs = Camino2Trackvis.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import FIRST


def test_FIRST_inputs():
    input_map = dict(
        affine_file=dict(argstr="-a %s", extensions=None, position=6,),
        args=dict(argstr="%s",),
        brain_extracted=dict(argstr="-b", position=2,),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="-i %s",
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=-2,
        ),
        list_of_specific_structures=dict(argstr="-s %s", position=5, sep=",",),
        method=dict(
            argstr="-m %s",
            position=4,
            usedefault=True,
            xor=["method_as_numerical_threshold"],
        ),
        method_as_numerical_threshold=dict(argstr="-m %.4f", position=4,),
        no_cleanup=dict(argstr="-d", position=3,),
        out_file=dict(
            argstr="-o %s",
            extensions=None,
            hash_files=False,
            mandatory=True,
            position=-1,
            usedefault=True,
        ),
        output_type=dict(),
        verbose=dict(argstr="-v", position=1,),
    )
    inputs = FIRST.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FIRST_outputs():
    output_map = dict(
        bvars=dict(),
        original_segmentations=dict(extensions=None,),
        segmentation_file=dict(extensions=None,),
        vtk_surfaces=dict(),
    )
    outputs = FIRST.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..epi import EddyQuad


def test_EddyQuad_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        base_name=dict(argstr="%s", position=0, usedefault=True,),
        bval_file=dict(argstr="--bvals %s", extensions=None, mandatory=True,),
        bvec_file=dict(argstr="--bvecs %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        field=dict(argstr="--field %s", extensions=None,),
        idx_file=dict(argstr="--eddyIdx %s", extensions=None, mandatory=True,),
        mask_file=dict(argstr="--mask %s", extensions=None, mandatory=True,),
        output_dir=dict(
            argstr="--output-dir %s", name_source=["base_name"], name_template="%s.qc",
        ),
        output_type=dict(),
        param_file=dict(argstr="--eddyParams %s", extensions=None, mandatory=True,),
        slice_spec=dict(argstr="--slspec %s", extensions=None,),
        verbose=dict(argstr="--verbose",),
    )
    inputs = EddyQuad.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_EddyQuad_outputs():
    output_map = dict(
        avg_b0_pe_png=dict(),
        avg_b_png=dict(),
        clean_volumes=dict(extensions=None,),
        cnr_png=dict(),
        qc_json=dict(extensions=None,),
        qc_pdf=dict(extensions=None,),
        residuals=dict(extensions=None,),
        vdm_png=dict(extensions=None,),
    )
    outputs = EddyQuad.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..surface import MergeModels


def test_MergeModels_inputs():
    input_map = dict(
        Model1=dict(argstr="%s", extensions=None, position=-3,),
        Model2=dict(argstr="%s", extensions=None, position=-2,),
        ModelOutput=dict(argstr="%s", hash_files=False, position=-1,),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
    )
    inputs = MergeModels.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MergeModels_outputs():
    output_map = dict(ModelOutput=dict(extensions=None, position=-1,),)
    outputs = MergeModels.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Means


def test_Means_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        count=dict(argstr="-count",),
        datum=dict(argstr="-datum %s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file_a=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        in_file_b=dict(argstr="%s", extensions=None, position=-1,),
        mask_inter=dict(argstr="-mask_inter",),
        mask_union=dict(argstr="-mask_union",),
        non_zero=dict(argstr="-non_zero",),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source="in_file_a",
            name_template="%s_mean",
        ),
        outputtype=dict(),
        scale=dict(argstr="-%sscale",),
        sqr=dict(argstr="-sqr",),
        std_dev=dict(argstr="-stdev",),
        summ=dict(argstr="-sum",),
    )
    inputs = Means.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Means_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Means.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..io import FreeSurferSource


def test_FreeSurferSource_inputs():
    input_map = dict(
        hemi=dict(usedefault=True,),
        subject_id=dict(mandatory=True,),
        subjects_dir=dict(mandatory=True,),
    )
    inputs = FreeSurferSource.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FreeSurferSource_outputs():
    output_map = dict(
        BA_stats=dict(altkey="BA", loc="stats",),
        T1=dict(extensions=None, loc="mri",),
        annot=dict(altkey="*annot", loc="label",),
        aparc_a2009s_stats=dict(altkey="aparc.a2009s", loc="stats",),
        aparc_aseg=dict(altkey="aparc*aseg", loc="mri",),
        aparc_stats=dict(altkey="aparc", loc="stats",),
        area_pial=dict(altkey="area.pial", loc="surf",),
        aseg=dict(extensions=None, loc="mri",),
        aseg_stats=dict(altkey="aseg", loc="stats",),
        avg_curv=dict(loc="surf",),
        brain=dict(extensions=None, loc="mri",),
        brainmask=dict(extensions=None, loc="mri",),
        curv=dict(loc="surf",),
        curv_pial=dict(altkey="curv.pial", loc="surf",),
        curv_stats=dict(altkey="curv", loc="stats",),
        entorhinal_exvivo_stats=dict(altkey="entorhinal_exvivo", loc="stats",),
        filled=dict(extensions=None, loc="mri",),
        graymid=dict(altkey=["graymid", "midthickness"], loc="surf",),
        inflated=dict(loc="surf",),
        jacobian_white=dict(loc="surf",),
        label=dict(altkey="*label", loc="label",),
        norm=dict(extensions=None, loc="mri",),
        nu=dict(extensions=None, loc="mri",),
        orig=dict(extensions=None, loc="mri",),
        pial=dict(loc="surf",),
        rawavg=dict(extensions=None, loc="mri",),
        ribbon=dict(altkey="*ribbon", loc="mri",),
        smoothwm=dict(loc="surf",),
        sphere=dict(loc="surf",),
        sphere_reg=dict(altkey="sphere.reg", loc="surf",),
        sulc=dict(loc="surf",),
        thickness=dict(loc="surf",),
        volume=dict(loc="surf",),
        white=dict(loc="surf",),
        wm=dict(extensions=None, loc="mri",),
        wmparc=dict(extensions=None, loc="mri",),
        wmparc_stats=dict(altkey="wmparc", loc="stats",),
    )
    outputs = FreeSurferSource.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..convert import AnalyzeHeader


def test_AnalyzeHeader_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        centre=dict(argstr="-centre %s", units="mm",),
        data_dims=dict(argstr="-datadims %s", units="voxels",),
        datatype=dict(argstr="-datatype %s", mandatory=True,),
        description=dict(argstr="-description %s",),
        environ=dict(nohash=True, usedefault=True,),
        greylevels=dict(argstr="-gl %s", units="NA",),
        in_file=dict(argstr="< %s", extensions=None, mandatory=True, position=1,),
        initfromheader=dict(argstr="-initfromheader %s", extensions=None, position=3,),
        intelbyteorder=dict(argstr="-intelbyteorder",),
        networkbyteorder=dict(argstr="-networkbyteorder",),
        nimages=dict(argstr="-nimages %d", units="NA",),
        offset=dict(argstr="-offset %d", units="NA",),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        picoseed=dict(argstr="-picoseed %s", units="mm",),
        printbigendian=dict(argstr="-printbigendian %s", extensions=None, position=3,),
        printimagedims=dict(argstr="-printimagedims %s", extensions=None, position=3,),
        printintelbyteorder=dict(
            argstr="-printintelbyteorder %s", extensions=None, position=3,
        ),
        printprogargs=dict(argstr="-printprogargs %s", extensions=None, position=3,),
        readheader=dict(argstr="-readheader %s", extensions=None, position=3,),
        scaleinter=dict(argstr="-scaleinter %d", units="NA",),
        scaleslope=dict(argstr="-scaleslope %d", units="NA",),
        scheme_file=dict(argstr="%s", extensions=None, position=2,),
        voxel_dims=dict(argstr="-voxeldims %s", units="mm",),
    )
    inputs = AnalyzeHeader.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_AnalyzeHeader_outputs():
    output_map = dict(header=dict(extensions=None,),)
    outputs = AnalyzeHeader.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..specialized import BRAINSConstellationDetector


def test_BRAINSConstellationDetector_inputs():
    input_map = dict(
        BackgroundFillValue=dict(argstr="--BackgroundFillValue %s",),
        LLSModel=dict(argstr="--LLSModel %s", extensions=None,),
        acLowerBound=dict(argstr="--acLowerBound %f",),
        args=dict(argstr="%s",),
        atlasLandmarkWeights=dict(argstr="--atlasLandmarkWeights %s", extensions=None,),
        atlasLandmarks=dict(argstr="--atlasLandmarks %s", extensions=None,),
        atlasVolume=dict(argstr="--atlasVolume %s", extensions=None,),
        cutOutHeadInOutputVolume=dict(argstr="--cutOutHeadInOutputVolume ",),
        debug=dict(argstr="--debug ",),
        environ=dict(nohash=True, usedefault=True,),
        forceACPoint=dict(argstr="--forceACPoint %s", sep=",",),
        forceHoughEyeDetectorReportFailure=dict(
            argstr="--forceHoughEyeDetectorReportFailure ",
        ),
        forcePCPoint=dict(argstr="--forcePCPoint %s", sep=",",),
        forceRPPoint=dict(argstr="--forceRPPoint %s", sep=",",),
        forceVN4Point=dict(argstr="--forceVN4Point %s", sep=",",),
        houghEyeDetectorMode=dict(argstr="--houghEyeDetectorMode %d",),
        inputLandmarksEMSP=dict(argstr="--inputLandmarksEMSP %s", extensions=None,),
        inputTemplateModel=dict(argstr="--inputTemplateModel %s", extensions=None,),
        inputVolume=dict(argstr="--inputVolume %s", extensions=None,),
        interpolationMode=dict(argstr="--interpolationMode %s",),
        mspQualityLevel=dict(argstr="--mspQualityLevel %d",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        otsuPercentileThreshold=dict(argstr="--otsuPercentileThreshold %f",),
        outputLandmarksInACPCAlignedSpace=dict(
            argstr="--outputLandmarksInACPCAlignedSpace %s", hash_files=False,
        ),
        outputLandmarksInInputSpace=dict(
            argstr="--outputLandmarksInInputSpace %s", hash_files=False,
        ),
        outputMRML=dict(argstr="--outputMRML %s", hash_files=False,),
        outputResampledVolume=dict(
            argstr="--outputResampledVolume %s", hash_files=False,
        ),
        outputTransform=dict(argstr="--outputTransform %s", hash_files=False,),
        outputUntransformedClippedVolume=dict(
            argstr="--outputUntransformedClippedVolume %s", hash_files=False,
        ),
        outputVerificationScript=dict(
            argstr="--outputVerificationScript %s", hash_files=False,
        ),
        outputVolume=dict(argstr="--outputVolume %s", hash_files=False,),
        rVN4=dict(argstr="--rVN4 %f",),
        rac=dict(argstr="--rac %f",),
        rescaleIntensities=dict(argstr="--rescaleIntensities ",),
        rescaleIntensitiesOutputRange=dict(
            argstr="--rescaleIntensitiesOutputRange %s", sep=",",
        ),
        resultsDir=dict(argstr="--resultsDir %s", hash_files=False,),
        rmpj=dict(argstr="--rmpj %f",),
        rpc=dict(argstr="--rpc %f",),
        trimRescaledIntensities=dict(argstr="--trimRescaledIntensities %f",),
        verbose=dict(argstr="--verbose ",),
        writeBranded2DImage=dict(argstr="--writeBranded2DImage %s", hash_files=False,),
        writedebuggingImagesLevel=dict(argstr="--writedebuggingImagesLevel %d",),
    )
    inputs = BRAINSConstellationDetector.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSConstellationDetector_outputs():
    output_map = dict(
        outputLandmarksInACPCAlignedSpace=dict(extensions=None,),
        outputLandmarksInInputSpace=dict(extensions=None,),
        outputMRML=dict(extensions=None,),
        outputResampledVolume=dict(extensions=None,),
        outputTransform=dict(extensions=None,),
        outputUntransformedClippedVolume=dict(extensions=None,),
        outputVerificationScript=dict(extensions=None,),
        outputVolume=dict(extensions=None,),
        resultsDir=dict(),
        writeBranded2DImage=dict(extensions=None,),
    )
    outputs = BRAINSConstellationDetector.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..specialized import BRAINSDemonWarp


def test_BRAINSDemonWarp_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        arrayOfPyramidLevelIterations=dict(
            argstr="--arrayOfPyramidLevelIterations %s", sep=",",
        ),
        backgroundFillValue=dict(argstr="--backgroundFillValue %d",),
        checkerboardPatternSubdivisions=dict(
            argstr="--checkerboardPatternSubdivisions %s", sep=",",
        ),
        environ=dict(nohash=True, usedefault=True,),
        fixedBinaryVolume=dict(argstr="--fixedBinaryVolume %s", extensions=None,),
        fixedVolume=dict(argstr="--fixedVolume %s", extensions=None,),
        gradient_type=dict(argstr="--gradient_type %s",),
        gui=dict(argstr="--gui ",),
        histogramMatch=dict(argstr="--histogramMatch ",),
        initializeWithDisplacementField=dict(
            argstr="--initializeWithDisplacementField %s", extensions=None,
        ),
        initializeWithTransform=dict(
            argstr="--initializeWithTransform %s", extensions=None,
        ),
        inputPixelType=dict(argstr="--inputPixelType %s",),
        interpolationMode=dict(argstr="--interpolationMode %s",),
        lowerThresholdForBOBF=dict(argstr="--lowerThresholdForBOBF %d",),
        maskProcessingMode=dict(argstr="--maskProcessingMode %s",),
        max_step_length=dict(argstr="--max_step_length %f",),
        medianFilterSize=dict(argstr="--medianFilterSize %s", sep=",",),
        minimumFixedPyramid=dict(argstr="--minimumFixedPyramid %s", sep=",",),
        minimumMovingPyramid=dict(argstr="--minimumMovingPyramid %s", sep=",",),
        movingBinaryVolume=dict(argstr="--movingBinaryVolume %s", extensions=None,),
        movingVolume=dict(argstr="--movingVolume %s", extensions=None,),
        neighborhoodForBOBF=dict(argstr="--neighborhoodForBOBF %s", sep=",",),
        numberOfBCHApproximationTerms=dict(
            argstr="--numberOfBCHApproximationTerms %d",
        ),
        numberOfHistogramBins=dict(argstr="--numberOfHistogramBins %d",),
        numberOfMatchPoints=dict(argstr="--numberOfMatchPoints %d",),
        numberOfPyramidLevels=dict(argstr="--numberOfPyramidLevels %d",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputCheckerboardVolume=dict(
            argstr="--outputCheckerboardVolume %s", hash_files=False,
        ),
        outputDebug=dict(argstr="--outputDebug ",),
        outputDisplacementFieldPrefix=dict(
            argstr="--outputDisplacementFieldPrefix %s",
        ),
        outputDisplacementFieldVolume=dict(
            argstr="--outputDisplacementFieldVolume %s", hash_files=False,
        ),
        outputNormalized=dict(argstr="--outputNormalized ",),
        outputPixelType=dict(argstr="--outputPixelType %s",),
        outputVolume=dict(argstr="--outputVolume %s", hash_files=False,),
        promptUser=dict(argstr="--promptUser ",),
        registrationFilterType=dict(argstr="--registrationFilterType %s",),
        seedForBOBF=dict(argstr="--seedForBOBF %s", sep=",",),
        smoothDisplacementFieldSigma=dict(argstr="--smoothDisplacementFieldSigma %f",),
        upFieldSmoothing=dict(argstr="--upFieldSmoothing %f",),
        upperThresholdForBOBF=dict(argstr="--upperThresholdForBOBF %d",),
        use_vanilla_dem=dict(argstr="--use_vanilla_dem ",),
    )
    inputs = BRAINSDemonWarp.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSDemonWarp_outputs():
    output_map = dict(
        outputCheckerboardVolume=dict(extensions=None,),
        outputDisplacementFieldVolume=dict(extensions=None,),
        outputVolume=dict(extensions=None,),
    )
    outputs = BRAINSDemonWarp.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..converters import BSplineToDeformationField


def test_BSplineToDeformationField_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        defImage=dict(argstr="--defImage %s", hash_files=False,),
        environ=dict(nohash=True, usedefault=True,),
        refImage=dict(argstr="--refImage %s", extensions=None,),
        tfm=dict(argstr="--tfm %s", extensions=None,),
    )
    inputs = BSplineToDeformationField.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BSplineToDeformationField_outputs():
    output_map = dict(defImage=dict(extensions=None,),)
    outputs = BSplineToDeformationField.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..misc import CreateNifti


def test_CreateNifti_inputs():
    input_map = dict(
        affine=dict(),
        data_file=dict(extensions=None, mandatory=True,),
        header_file=dict(extensions=None, mandatory=True,),
    )
    inputs = CreateNifti.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_CreateNifti_outputs():
    output_map = dict(nifti_file=dict(extensions=None,),)
    outputs = CreateNifti.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..misc import FuzzyOverlap


def test_FuzzyOverlap_inputs():
    input_map = dict(
        in_mask=dict(extensions=None,),
        in_ref=dict(mandatory=True,),
        in_tst=dict(mandatory=True,),
        out_file=dict(extensions=None, usedefault=True,),
        weighting=dict(usedefault=True,),
    )
    inputs = FuzzyOverlap.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FuzzyOverlap_outputs():
    output_map = dict(class_fdi=dict(), class_fji=dict(), dice=dict(), jaccard=dict(),)
    outputs = FuzzyOverlap.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Smooth


def test_Smooth_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        fwhm=dict(
            argstr="-kernel gauss %.03f -fmean",
            mandatory=True,
            position=1,
            xor=["sigma"],
        ),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=0,),
        output_type=dict(),
        sigma=dict(
            argstr="-kernel gauss %.03f -fmean",
            mandatory=True,
            position=1,
            xor=["fwhm"],
        ),
        smoothed_file=dict(
            argstr="%s",
            extensions=None,
            hash_files=False,
            name_source=["in_file"],
            name_template="%s_smooth",
            position=2,
        ),
    )
    inputs = Smooth.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Smooth_outputs():
    output_map = dict(smoothed_file=dict(extensions=None,),)
    outputs = Smooth.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..petpvc import PETPVC


def test_PETPVC_inputs():
    input_map = dict(
        alpha=dict(argstr="-a %.4f", usedefault=True,),
        args=dict(argstr="%s",),
        debug=dict(argstr="-d", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        fwhm_x=dict(argstr="-x %.4f", mandatory=True,),
        fwhm_y=dict(argstr="-y %.4f", mandatory=True,),
        fwhm_z=dict(argstr="-z %.4f", mandatory=True,),
        in_file=dict(argstr="-i %s", extensions=None, mandatory=True,),
        mask_file=dict(argstr="-m %s", extensions=None, mandatory=True,),
        n_deconv=dict(argstr="-k %d", usedefault=True,),
        n_iter=dict(argstr="-n %d", usedefault=True,),
        out_file=dict(argstr="-o %s", extensions=None, genfile=True, hash_files=False,),
        pvc=dict(argstr="-p %s", mandatory=True,),
        stop_crit=dict(argstr="-s %.4f", usedefault=True,),
    )
    inputs = PETPVC.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_PETPVC_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = PETPVC.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..developer import MedicAlgorithmThresholdToBinaryMask


def test_MedicAlgorithmThresholdToBinaryMask_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inLabel=dict(argstr="--inLabel %s", sep=";",),
        inMaximum=dict(argstr="--inMaximum %f",),
        inMinimum=dict(argstr="--inMinimum %f",),
        inUse=dict(argstr="--inUse %s",),
        null=dict(argstr="--null %s",),
        outBinary=dict(argstr="--outBinary %s", sep=";",),
        xDefaultMem=dict(argstr="-xDefaultMem %d",),
        xMaxProcess=dict(argstr="-xMaxProcess %d", usedefault=True,),
        xPrefExt=dict(argstr="--xPrefExt %s",),
    )
    inputs = MedicAlgorithmThresholdToBinaryMask.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MedicAlgorithmThresholdToBinaryMask_outputs():
    output_map = dict()
    outputs = MedicAlgorithmThresholdToBinaryMask.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import DICOMConvert


def test_DICOMConvert_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        base_output_dir=dict(mandatory=True,),
        dicom_dir=dict(mandatory=True,),
        dicom_info=dict(extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        file_mapping=dict(),
        ignore_single_slice=dict(requires=["dicom_info"],),
        out_type=dict(usedefault=True,),
        seq_list=dict(requires=["dicom_info"],),
        subject_dir_template=dict(usedefault=True,),
        subject_id=dict(),
        subjects_dir=dict(),
    )
    inputs = DICOMConvert.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import MRTransform


def test_MRTransform_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        debug=dict(argstr="-debug", position=1,),
        environ=dict(nohash=True, usedefault=True,),
        flip_x=dict(argstr="-flipx", position=1,),
        in_files=dict(argstr="%s", mandatory=True, position=-2,),
        invert=dict(argstr="-inverse", position=1,),
        out_filename=dict(argstr="%s", extensions=None, genfile=True, position=-1,),
        quiet=dict(argstr="-quiet", position=1,),
        reference_image=dict(argstr="-reference %s", extensions=None, position=1,),
        replace_transform=dict(argstr="-replace", position=1,),
        template_image=dict(argstr="-template %s", extensions=None, position=1,),
        transformation_file=dict(argstr="-transform %s", extensions=None, position=1,),
    )
    inputs = MRTransform.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MRTransform_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = MRTransform.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import MultipleRegressionDesign


def test_MultipleRegressionDesign_inputs():
    input_map = dict(
        covariates=dict(field="cov",),
        explicit_mask_file=dict(extensions=None, field="masking.em",),
        global_calc_mean=dict(
            field="globalc.g_mean", xor=["global_calc_omit", "global_calc_values"],
        ),
        global_calc_omit=dict(
            field="globalc.g_omit", xor=["global_calc_mean", "global_calc_values"],
        ),
        global_calc_values=dict(
            field="globalc.g_user.global_uval",
            xor=["global_calc_mean", "global_calc_omit"],
        ),
        global_normalization=dict(field="globalm.glonorm",),
        in_files=dict(field="des.mreg.scans", mandatory=True,),
        include_intercept=dict(field="des.mreg.incint", usedefault=True,),
        matlab_cmd=dict(),
        mfile=dict(usedefault=True,),
        no_grand_mean_scaling=dict(field="globalm.gmsca.gmsca_no",),
        paths=dict(),
        spm_mat_dir=dict(field="dir",),
        threshold_mask_absolute=dict(
            field="masking.tm.tma.athresh",
            xor=["threshold_mask_none", "threshold_mask_relative"],
        ),
        threshold_mask_none=dict(
            field="masking.tm.tm_none",
            xor=["threshold_mask_absolute", "threshold_mask_relative"],
        ),
        threshold_mask_relative=dict(
            field="masking.tm.tmr.rthresh",
            xor=["threshold_mask_absolute", "threshold_mask_none"],
        ),
        use_implicit_threshold=dict(field="masking.im",),
        use_mcr=dict(),
        use_v8struct=dict(min_ver="8", usedefault=True,),
        user_covariates=dict(field="des.mreg.mcov",),
    )
    inputs = MultipleRegressionDesign.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MultipleRegressionDesign_outputs():
    output_map = dict(spm_mat_file=dict(extensions=None,),)
    outputs = MultipleRegressionDesign.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..base import AFNICommand


def test_AFNICommand_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source=["in_file"],
            name_template="%s_afni",
        ),
        outputtype=dict(),
    )
    inputs = AFNICommand.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Undump


def test_Undump_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        coordinates_specification=dict(argstr="-%s",),
        datatype=dict(argstr="-datum %s",),
        default_value=dict(argstr="-dval %f",),
        environ=dict(nohash=True, usedefault=True,),
        fill_value=dict(argstr="-fval %f",),
        head_only=dict(argstr="-head_only",),
        in_file=dict(
            argstr="-master %s",
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=-1,
        ),
        mask_file=dict(argstr="-mask %s", extensions=None,),
        num_threads=dict(nohash=True, usedefault=True,),
        orient=dict(argstr="-orient %s",),
        out_file=dict(argstr="-prefix %s", extensions=None, name_source="in_file",),
        outputtype=dict(),
        srad=dict(argstr="-srad %f",),
    )
    inputs = Undump.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Undump_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Undump.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import MotionOutliers


def test_MotionOutliers_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        dummy=dict(argstr="--dummy=%d",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-i %s", extensions=None, mandatory=True,),
        mask=dict(argstr="-m %s", extensions=None,),
        metric=dict(argstr="--%s",),
        no_motion_correction=dict(argstr="--nomoco",),
        out_file=dict(
            argstr="-o %s",
            extensions=None,
            hash_files=False,
            keep_extension=True,
            name_source="in_file",
            name_template="%s_outliers.txt",
        ),
        out_metric_plot=dict(
            argstr="-p %s",
            extensions=None,
            hash_files=False,
            keep_extension=True,
            name_source="in_file",
            name_template="%s_metrics.png",
        ),
        out_metric_values=dict(
            argstr="-s %s",
            extensions=None,
            hash_files=False,
            keep_extension=True,
            name_source="in_file",
            name_template="%s_metrics.txt",
        ),
        output_type=dict(),
        threshold=dict(argstr="--thresh=%g",),
    )
    inputs = MotionOutliers.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MotionOutliers_outputs():
    output_map = dict(
        out_file=dict(extensions=None,),
        out_metric_plot=dict(extensions=None,),
        out_metric_values=dict(extensions=None,),
    )
    outputs = MotionOutliers.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..base import Select


def test_Select_inputs():
    input_map = dict(index=dict(mandatory=True,), inlist=dict(mandatory=True,),)
    inputs = Select.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Select_outputs():
    output_map = dict(out=dict(),)
    outputs = Select.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..fix import AccuracyTester


def test_AccuracyTester_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        mel_icas=dict(argstr="%s", copyfile=False, mandatory=True, position=3,),
        output_directory=dict(argstr="%s", mandatory=True, position=2,),
        trained_wts_file=dict(
            argstr="%s", extensions=None, mandatory=True, position=1,
        ),
    )
    inputs = AccuracyTester.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_AccuracyTester_outputs():
    output_map = dict(output_directory=dict(argstr="%s", position=1,),)
    outputs = AccuracyTester.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import Randomise


def test_Randomise_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        base_name=dict(argstr='-o "%s"', position=1, usedefault=True,),
        c_thresh=dict(argstr="-c %.1f",),
        cm_thresh=dict(argstr="-C %.1f",),
        demean=dict(argstr="-D",),
        design_mat=dict(argstr="-d %s", extensions=None, position=2,),
        environ=dict(nohash=True, usedefault=True,),
        f_c_thresh=dict(argstr="-F %.2f",),
        f_cm_thresh=dict(argstr="-S %.2f",),
        f_only=dict(argstr="--f_only",),
        fcon=dict(argstr="-f %s", extensions=None,),
        in_file=dict(argstr="-i %s", extensions=None, mandatory=True, position=0,),
        mask=dict(argstr="-m %s", extensions=None,),
        num_perm=dict(argstr="-n %d",),
        one_sample_group_mean=dict(argstr="-1",),
        output_type=dict(),
        p_vec_n_dist_files=dict(argstr="-P",),
        raw_stats_imgs=dict(argstr="-R",),
        seed=dict(argstr="--seed=%d",),
        show_info_parallel_mode=dict(argstr="-Q",),
        show_total_perms=dict(argstr="-q",),
        tcon=dict(argstr="-t %s", extensions=None, position=3,),
        tfce=dict(argstr="-T",),
        tfce2D=dict(argstr="--T2",),
        tfce_C=dict(argstr="--tfce_C=%.2f",),
        tfce_E=dict(argstr="--tfce_E=%.2f",),
        tfce_H=dict(argstr="--tfce_H=%.2f",),
        var_smooth=dict(argstr="-v %d",),
        vox_p_values=dict(argstr="-x",),
        x_block_labels=dict(argstr="-e %s", extensions=None,),
    )
    inputs = Randomise.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Randomise_outputs():
    output_map = dict(
        f_corrected_p_files=dict(),
        f_p_files=dict(),
        fstat_files=dict(),
        t_corrected_p_files=dict(),
        t_p_files=dict(),
        tstat_files=dict(),
    )
    outputs = Randomise.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import SegStats


def test_SegStats_inputs():
    input_map = dict(
        annot=dict(
            argstr="--annot %s %s %s",
            mandatory=True,
            xor=("segmentation_file", "annot", "surf_label"),
        ),
        args=dict(argstr="%s",),
        avgwf_file=dict(argstr="--avgwfvol %s",),
        avgwf_txt_file=dict(argstr="--avgwf %s",),
        brain_vol=dict(argstr="--%s",),
        brainmask_file=dict(argstr="--brainmask %s", extensions=None,),
        calc_power=dict(argstr="--%s",),
        calc_snr=dict(argstr="--snr",),
        color_table_file=dict(
            argstr="--ctab %s",
            extensions=None,
            xor=("color_table_file", "default_color_table", "gca_color_table"),
        ),
        cortex_vol_from_surf=dict(argstr="--surf-ctx-vol",),
        default_color_table=dict(
            argstr="--ctab-default",
            xor=("color_table_file", "default_color_table", "gca_color_table"),
        ),
        empty=dict(argstr="--empty",),
        environ=dict(nohash=True, usedefault=True,),
        etiv=dict(argstr="--etiv",),
        etiv_only=dict(),
        euler=dict(argstr="--euler",),
        exclude_ctx_gm_wm=dict(argstr="--excl-ctxgmwm",),
        exclude_id=dict(argstr="--excludeid %d",),
        frame=dict(argstr="--frame %d",),
        gca_color_table=dict(
            argstr="--ctab-gca %s",
            extensions=None,
            xor=("color_table_file", "default_color_table", "gca_color_table"),
        ),
        in_file=dict(argstr="--i %s", extensions=None,),
        in_intensity=dict(argstr="--in %s --in-intensity-name %s", extensions=None,),
        intensity_units=dict(
            argstr="--in-intensity-units %s", requires=["in_intensity"],
        ),
        mask_erode=dict(argstr="--maskerode %d",),
        mask_file=dict(argstr="--mask %s", extensions=None,),
        mask_frame=dict(requires=["mask_file"],),
        mask_invert=dict(argstr="--maskinvert",),
        mask_sign=dict(),
        mask_thresh=dict(argstr="--maskthresh %f",),
        multiply=dict(argstr="--mul %f",),
        non_empty_only=dict(argstr="--nonempty",),
        partial_volume_file=dict(argstr="--pv %s", extensions=None,),
        segment_id=dict(argstr="--id %s...",),
        segmentation_file=dict(
            argstr="--seg %s",
            extensions=None,
            mandatory=True,
            xor=("segmentation_file", "annot", "surf_label"),
        ),
        sf_avg_file=dict(argstr="--sfavg %s",),
        subcort_gm=dict(argstr="--subcortgray",),
        subjects_dir=dict(),
        summary_file=dict(
            argstr="--sum %s", extensions=None, genfile=True, position=-1,
        ),
        supratent=dict(argstr="--supratent",),
        surf_label=dict(
            argstr="--slabel %s %s %s",
            mandatory=True,
            xor=("segmentation_file", "annot", "surf_label"),
        ),
        total_gray=dict(argstr="--totalgray",),
        vox=dict(argstr="--vox %s",),
        wm_vol_from_surf=dict(argstr="--surf-wm-vol",),
    )
    inputs = SegStats.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SegStats_outputs():
    output_map = dict(
        avgwf_file=dict(extensions=None,),
        avgwf_txt_file=dict(extensions=None,),
        sf_avg_file=dict(extensions=None,),
        summary_file=dict(extensions=None,),
    )
    outputs = SegStats.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import FilterRegressor


def test_FilterRegressor_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        design_file=dict(argstr="-d %s", extensions=None, mandatory=True, position=3,),
        environ=dict(nohash=True, usedefault=True,),
        filter_all=dict(
            argstr="-f '%s'", mandatory=True, position=4, xor=["filter_columns"],
        ),
        filter_columns=dict(
            argstr="-f '%s'", mandatory=True, position=4, xor=["filter_all"],
        ),
        in_file=dict(argstr="-i %s", extensions=None, mandatory=True, position=1,),
        mask=dict(argstr="-m %s", extensions=None,),
        out_file=dict(
            argstr="-o %s", extensions=None, genfile=True, hash_files=False, position=2,
        ),
        out_vnscales=dict(argstr="--out_vnscales",),
        output_type=dict(),
        var_norm=dict(argstr="--vn",),
    )
    inputs = FilterRegressor.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FilterRegressor_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = FilterRegressor.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..specialized import BRAINSROIAuto


def test_BRAINSROIAuto_inputs():
    input_map = dict(
        ROIAutoDilateSize=dict(argstr="--ROIAutoDilateSize %f",),
        args=dict(argstr="%s",),
        closingSize=dict(argstr="--closingSize %f",),
        cropOutput=dict(argstr="--cropOutput ",),
        environ=dict(nohash=True, usedefault=True,),
        inputVolume=dict(argstr="--inputVolume %s", extensions=None,),
        maskOutput=dict(argstr="--maskOutput ",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        otsuPercentileThreshold=dict(argstr="--otsuPercentileThreshold %f",),
        outputROIMaskVolume=dict(argstr="--outputROIMaskVolume %s", hash_files=False,),
        outputVolume=dict(argstr="--outputVolume %s", hash_files=False,),
        outputVolumePixelType=dict(argstr="--outputVolumePixelType %s",),
        thresholdCorrectionFactor=dict(argstr="--thresholdCorrectionFactor %f",),
    )
    inputs = BRAINSROIAuto.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSROIAuto_outputs():
    output_map = dict(
        outputROIMaskVolume=dict(extensions=None,), outputVolume=dict(extensions=None,),
    )
    outputs = BRAINSROIAuto.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..registration import scalartransform


def test_scalartransform_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        deformation=dict(argstr="--deformation %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        h_field=dict(argstr="--h_field ",),
        input_image=dict(argstr="--input_image %s", extensions=None,),
        interpolation=dict(argstr="--interpolation %s",),
        invert=dict(argstr="--invert ",),
        output_image=dict(argstr="--output_image %s", hash_files=False,),
        transformation=dict(argstr="--transformation %s", hash_files=False,),
    )
    inputs = scalartransform.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_scalartransform_outputs():
    output_map = dict(
        output_image=dict(extensions=None,), transformation=dict(extensions=None,),
    )
    outputs = scalartransform.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..registration import DiffeoScalarVol


def test_DiffeoScalarVol_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        flip=dict(argstr="-flip %d %d %d",),
        in_file=dict(argstr="-in %s", extensions=None, mandatory=True,),
        interpolation=dict(argstr="-interp %s", usedefault=True,),
        out_file=dict(
            argstr="-out %s",
            extensions=None,
            keep_extension=True,
            name_source="in_file",
            name_template="%s_diffeoxfmd",
        ),
        resampling_type=dict(argstr="-type %s",),
        target=dict(argstr="-target %s", extensions=None, xor=["voxel_size"],),
        transform=dict(argstr="-trans %s", extensions=None, mandatory=True,),
        voxel_size=dict(argstr="-vsize %g %g %g", xor=["target"],),
    )
    inputs = DiffeoScalarVol.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DiffeoScalarVol_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = DiffeoScalarVol.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..convert import Image2Voxel


def test_Image2Voxel_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="-4dimage %s", extensions=None, mandatory=True, position=1,
        ),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        out_type=dict(argstr="-outputdatatype %s", position=2, usedefault=True,),
    )
    inputs = Image2Voxel.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Image2Voxel_outputs():
    output_map = dict(voxel_order=dict(extensions=None,),)
    outputs = Image2Voxel.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..calib import SFPICOCalibData


def test_SFPICOCalibData_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        info_file=dict(
            argstr="-infooutputfile %s",
            extensions=None,
            genfile=True,
            hash_files=False,
            mandatory=True,
        ),
        onedtfarange=dict(argstr="-onedtfarange %s", units="NA",),
        onedtfastep=dict(argstr="-onedtfastep %f", units="NA",),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        scheme_file=dict(argstr="-schemefile %s", extensions=None, mandatory=True,),
        seed=dict(argstr="-seed %f", units="NA",),
        snr=dict(argstr="-snr %f", units="NA",),
        trace=dict(argstr="-trace %f", units="NA",),
        twodtanglerange=dict(argstr="-twodtanglerange %s", units="NA",),
        twodtanglestep=dict(argstr="-twodtanglestep %f", units="NA",),
        twodtfarange=dict(argstr="-twodtfarange %s", units="NA",),
        twodtfastep=dict(argstr="-twodtfastep %f", units="NA",),
        twodtmixmax=dict(argstr="-twodtmixmax %f", units="NA",),
        twodtmixstep=dict(argstr="-twodtmixstep %f", units="NA",),
    )
    inputs = SFPICOCalibData.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SFPICOCalibData_outputs():
    output_map = dict(
        PICOCalib=dict(extensions=None,), calib_info=dict(extensions=None,),
    )
    outputs = SFPICOCalibData.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..c3 import C3dAffineTool


def test_C3dAffineTool_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        fsl2ras=dict(argstr="-fsl2ras", position=4,),
        itk_transform=dict(argstr="-oitk %s", hash_files=False, position=5,),
        reference_file=dict(argstr="-ref %s", extensions=None, position=1,),
        source_file=dict(argstr="-src %s", extensions=None, position=2,),
        transform_file=dict(argstr="%s", extensions=None, position=3,),
    )
    inputs = C3dAffineTool.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_C3dAffineTool_outputs():
    output_map = dict(itk_transform=dict(extensions=None,),)
    outputs = C3dAffineTool.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..developer import JistBrainPartialVolumeFilter


def test_JistBrainPartialVolumeFilter_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inInput=dict(argstr="--inInput %s", extensions=None,),
        inPV=dict(argstr="--inPV %s",),
        inoutput=dict(argstr="--inoutput %s",),
        null=dict(argstr="--null %s",),
        outPartial=dict(argstr="--outPartial %s", hash_files=False,),
        xDefaultMem=dict(argstr="-xDefaultMem %d",),
        xMaxProcess=dict(argstr="-xMaxProcess %d", usedefault=True,),
        xPrefExt=dict(argstr="--xPrefExt %s",),
    )
    inputs = JistBrainPartialVolumeFilter.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_JistBrainPartialVolumeFilter_outputs():
    output_map = dict(outPartial=dict(extensions=None,),)
    outputs = JistBrainPartialVolumeFilter.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..minc import BBox


def test_BBox_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        format_minccrop=dict(argstr="-minccrop",),
        format_mincresample=dict(argstr="-mincresample",),
        format_mincreshape=dict(argstr="-mincreshape",),
        input_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        one_line=dict(argstr="-one_line", xor=("one_line", "two_lines"),),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        output_file=dict(
            extensions=None,
            hash_files=False,
            keep_extension=False,
            name_source=["input_file"],
            name_template="%s_bbox.txt",
            position=-1,
        ),
        threshold=dict(argstr="-threshold",),
        two_lines=dict(argstr="-two_lines", xor=("one_line", "two_lines"),),
    )
    inputs = BBox.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BBox_outputs():
    output_map = dict(output_file=dict(extensions=None,),)
    outputs = BBox.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import CheckTalairachAlignment


def test_CheckTalairachAlignment_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="-xfm %s",
            extensions=None,
            mandatory=True,
            position=-1,
            xor=["subject"],
        ),
        subject=dict(argstr="-subj %s", mandatory=True, position=-1, xor=["in_file"],),
        subjects_dir=dict(),
        threshold=dict(argstr="-T %.3f", usedefault=True,),
    )
    inputs = CheckTalairachAlignment.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_CheckTalairachAlignment_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = CheckTalairachAlignment.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utilities import GeneratePurePlugMask


def test_GeneratePurePlugMask_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputImageModalities=dict(argstr="--inputImageModalities %s...",),
        numberOfSubSamples=dict(argstr="--numberOfSubSamples %s", sep=",",),
        outputMaskFile=dict(argstr="--outputMaskFile %s", hash_files=False,),
        threshold=dict(argstr="--threshold %f",),
    )
    inputs = GeneratePurePlugMask.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_GeneratePurePlugMask_outputs():
    output_map = dict(outputMaskFile=dict(extensions=None,),)
    outputs = GeneratePurePlugMask.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brains import BRAINSLmkTransform


def test_BRAINSLmkTransform_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputFixedLandmarks=dict(argstr="--inputFixedLandmarks %s", extensions=None,),
        inputMovingLandmarks=dict(argstr="--inputMovingLandmarks %s", extensions=None,),
        inputMovingVolume=dict(argstr="--inputMovingVolume %s", extensions=None,),
        inputReferenceVolume=dict(argstr="--inputReferenceVolume %s", extensions=None,),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputAffineTransform=dict(
            argstr="--outputAffineTransform %s", hash_files=False,
        ),
        outputResampledVolume=dict(
            argstr="--outputResampledVolume %s", hash_files=False,
        ),
    )
    inputs = BRAINSLmkTransform.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSLmkTransform_outputs():
    output_map = dict(
        outputAffineTransform=dict(extensions=None,),
        outputResampledVolume=dict(extensions=None,),
    )
    outputs = BRAINSLmkTransform.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..tracking import SphericallyDeconvolutedStreamlineTrack


def test_SphericallyDeconvolutedStreamlineTrack_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        cutoff_value=dict(argstr="-cutoff %s", units="NA",),
        desired_number_of_tracks=dict(argstr="-number %d",),
        do_not_precompute=dict(argstr="-noprecomputed",),
        environ=dict(nohash=True, usedefault=True,),
        exclude_file=dict(
            argstr="-exclude %s", extensions=None, xor=["exclude_file", "exclude_spec"],
        ),
        exclude_spec=dict(
            argstr="-exclude %s",
            position=2,
            sep=",",
            units="mm",
            xor=["exclude_file", "exclude_spec"],
        ),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        include_file=dict(
            argstr="-include %s", extensions=None, xor=["include_file", "include_spec"],
        ),
        include_spec=dict(
            argstr="-include %s",
            position=2,
            sep=",",
            units="mm",
            xor=["include_file", "include_spec"],
        ),
        initial_cutoff_value=dict(argstr="-initcutoff %s", units="NA",),
        initial_direction=dict(argstr="-initdirection %s", units="voxels",),
        inputmodel=dict(argstr="%s", position=-3, usedefault=True,),
        mask_file=dict(
            argstr="-mask %s", extensions=None, xor=["mask_file", "mask_spec"],
        ),
        mask_spec=dict(
            argstr="-mask %s",
            position=2,
            sep=",",
            units="mm",
            xor=["mask_file", "mask_spec"],
        ),
        maximum_number_of_tracks=dict(argstr="-maxnum %d",),
        maximum_tract_length=dict(argstr="-length %s", units="mm",),
        minimum_radius_of_curvature=dict(argstr="-curvature %s", units="mm",),
        minimum_tract_length=dict(argstr="-minlength %s", units="mm",),
        no_mask_interpolation=dict(argstr="-nomaskinterp",),
        out_file=dict(
            argstr="%s",
            extensions=None,
            name_source=["in_file"],
            name_template="%s_tracked.tck",
            output_name="tracked",
            position=-1,
        ),
        seed_file=dict(
            argstr="-seed %s", extensions=None, xor=["seed_file", "seed_spec"],
        ),
        seed_spec=dict(
            argstr="-seed %s",
            position=2,
            sep=",",
            units="mm",
            xor=["seed_file", "seed_spec"],
        ),
        step_size=dict(argstr="-step %s", units="mm",),
        stop=dict(argstr="-stop",),
        unidirectional=dict(argstr="-unidirectional",),
    )
    inputs = SphericallyDeconvolutedStreamlineTrack.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SphericallyDeconvolutedStreamlineTrack_outputs():
    output_map = dict(tracked=dict(extensions=None,),)
    outputs = SphericallyDeconvolutedStreamlineTrack.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..gtract import gtractResampleB0


def test_gtractResampleB0_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputAnatomicalVolume=dict(
            argstr="--inputAnatomicalVolume %s", extensions=None,
        ),
        inputTransform=dict(argstr="--inputTransform %s", extensions=None,),
        inputVolume=dict(argstr="--inputVolume %s", extensions=None,),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputVolume=dict(argstr="--outputVolume %s", hash_files=False,),
        transformType=dict(argstr="--transformType %s",),
        vectorIndex=dict(argstr="--vectorIndex %d",),
    )
    inputs = gtractResampleB0.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_gtractResampleB0_outputs():
    output_map = dict(outputVolume=dict(extensions=None,),)
    outputs = gtractResampleB0.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import ThresholdImage


def test_ThresholdImage_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        copy_header=dict(mandatory=True, usedefault=True,),
        dimension=dict(argstr="%d", position=1, usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        input_image=dict(argstr="%s", extensions=None, mandatory=True, position=2,),
        input_mask=dict(argstr="%s", extensions=None, requires=["num_thresholds"],),
        inside_value=dict(argstr="%f", position=6, requires=["th_low"],),
        mode=dict(
            argstr="%s",
            position=4,
            requires=["num_thresholds"],
            xor=["th_low", "th_high"],
        ),
        num_threads=dict(nohash=True, usedefault=True,),
        num_thresholds=dict(argstr="%d", position=5,),
        output_image=dict(
            argstr="%s",
            extensions=None,
            keep_extension=True,
            name_source=["input_image"],
            name_template="%s_resampled",
            position=3,
        ),
        outside_value=dict(argstr="%f", position=7, requires=["th_low"],),
        th_high=dict(argstr="%f", position=5, xor=["mode"],),
        th_low=dict(argstr="%f", position=4, xor=["mode"],),
    )
    inputs = ThresholdImage.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ThresholdImage_outputs():
    output_map = dict(output_image=dict(extensions=None,),)
    outputs = ThresholdImage.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Smooth


def test_Smooth_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="--i %s", extensions=None, mandatory=True,),
        num_iters=dict(argstr="--niters %d", mandatory=True, xor=["surface_fwhm"],),
        proj_frac=dict(argstr="--projfrac %s", xor=["proj_frac_avg"],),
        proj_frac_avg=dict(argstr="--projfrac-avg %.2f %.2f %.2f", xor=["proj_frac"],),
        reg_file=dict(argstr="--reg %s", extensions=None, mandatory=True,),
        smoothed_file=dict(argstr="--o %s", extensions=None, genfile=True,),
        subjects_dir=dict(),
        surface_fwhm=dict(
            argstr="--fwhm %f",
            mandatory=True,
            requires=["reg_file"],
            xor=["num_iters"],
        ),
        vol_fwhm=dict(argstr="--vol-fwhm %f",),
    )
    inputs = Smooth.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Smooth_outputs():
    output_map = dict(smoothed_file=dict(extensions=None,),)
    outputs = Smooth.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Resample


def test_Resample_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="-inset %s",
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=-1,
        ),
        master=dict(argstr="-master %s", extensions=None,),
        num_threads=dict(nohash=True, usedefault=True,),
        orientation=dict(argstr="-orient %s",),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source="in_file",
            name_template="%s_resample",
        ),
        outputtype=dict(),
        resample_mode=dict(argstr="-rmode %s",),
        voxel_size=dict(argstr="-dxyz %f %f %f",),
    )
    inputs = Resample.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Resample_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Resample.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utilities import HistogramMatchingFilter


def test_HistogramMatchingFilter_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        histogramAlgorithm=dict(argstr="--histogramAlgorithm %s",),
        inputBinaryVolume=dict(argstr="--inputBinaryVolume %s", extensions=None,),
        inputVolume=dict(argstr="--inputVolume %s", extensions=None,),
        numberOfHistogramBins=dict(argstr="--numberOfHistogramBins %d",),
        numberOfMatchPoints=dict(argstr="--numberOfMatchPoints %d",),
        outputVolume=dict(argstr="--outputVolume %s", hash_files=False,),
        referenceBinaryVolume=dict(
            argstr="--referenceBinaryVolume %s", extensions=None,
        ),
        referenceVolume=dict(argstr="--referenceVolume %s", extensions=None,),
        verbose=dict(argstr="--verbose ",),
        writeHistogram=dict(argstr="--writeHistogram %s",),
    )
    inputs = HistogramMatchingFilter.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_HistogramMatchingFilter_outputs():
    output_map = dict(outputVolume=dict(extensions=None,),)
    outputs = HistogramMatchingFilter.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..segmentation import CorticalThickness


def test_CorticalThickness_inputs():
    input_map = dict(
        anatomical_image=dict(argstr="-a %s", extensions=None, mandatory=True,),
        args=dict(argstr="%s",),
        b_spline_smoothing=dict(argstr="-v",),
        brain_probability_mask=dict(
            argstr="-m %s", copyfile=False, extensions=None, mandatory=True,
        ),
        brain_template=dict(argstr="-e %s", extensions=None, mandatory=True,),
        cortical_label_image=dict(extensions=None,),
        debug=dict(argstr="-z 1",),
        dimension=dict(argstr="-d %d", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        extraction_registration_mask=dict(argstr="-f %s", extensions=None,),
        image_suffix=dict(argstr="-s %s", usedefault=True,),
        keep_temporary_files=dict(argstr="-k %d",),
        label_propagation=dict(argstr="-l %s",),
        max_iterations=dict(argstr="-i %d",),
        num_threads=dict(nohash=True, usedefault=True,),
        out_prefix=dict(argstr="-o %s", usedefault=True,),
        posterior_formulation=dict(argstr="-b %s",),
        prior_segmentation_weight=dict(argstr="-w %f",),
        quick_registration=dict(argstr="-q 1",),
        segmentation_iterations=dict(argstr="-n %d",),
        segmentation_priors=dict(argstr="-p %s", mandatory=True,),
        t1_registration_template=dict(argstr="-t %s", extensions=None, mandatory=True,),
        use_floatingpoint_precision=dict(argstr="-j %d",),
        use_random_seeding=dict(argstr="-u %d",),
    )
    inputs = CorticalThickness.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_CorticalThickness_outputs():
    output_map = dict(
        BrainExtractionMask=dict(extensions=None,),
        BrainSegmentation=dict(extensions=None,),
        BrainSegmentationN4=dict(extensions=None,),
        BrainSegmentationPosteriors=dict(),
        BrainVolumes=dict(extensions=None,),
        CorticalThickness=dict(extensions=None,),
        CorticalThicknessNormedToTemplate=dict(extensions=None,),
        ExtractedBrainN4=dict(extensions=None,),
        SubjectToTemplate0GenericAffine=dict(extensions=None,),
        SubjectToTemplate1Warp=dict(extensions=None,),
        SubjectToTemplateLogJacobian=dict(extensions=None,),
        TemplateToSubject0Warp=dict(extensions=None,),
        TemplateToSubject1GenericAffine=dict(extensions=None,),
    )
    outputs = CorticalThickness.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import EstimateContrast


def test_EstimateContrast_inputs():
    input_map = dict(
        axis=dict(mandatory=True,),
        beta=dict(extensions=None, mandatory=True,),
        constants=dict(mandatory=True,),
        contrasts=dict(mandatory=True,),
        dof=dict(mandatory=True,),
        mask=dict(extensions=None,),
        nvbeta=dict(mandatory=True,),
        reg_names=dict(mandatory=True,),
        s2=dict(extensions=None, mandatory=True,),
    )
    inputs = EstimateContrast.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_EstimateContrast_outputs():
    output_map = dict(p_maps=dict(), stat_maps=dict(), z_maps=dict(),)
    outputs = EstimateContrast.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
